==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/GROUPWOAUTHID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour GROUPWOAUTHID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GROUPWOAUTHID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GROUPWOSTATUSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GROUPWOAUTHID_Type", propOrder = {
    "usergroupid",
    "workordertype",
    "groupwostatusid"
})
public class GROUPWOAUTHID_Type {

    @XmlElement(name = "USERGROUPID", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "WORKORDERTYPE", required = true)
    protected TYPE_Type workordertype;
    @XmlElement(name = "GROUPWOSTATUSID", required = true)
    protected GROUPWOSTATUSID_Type groupwostatusid;

    /**
     * Obtient la valeur de la propriété usergroupid.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Définit la valeur de la propriété usergroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Obtient la valeur de la propriété workordertype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWORKORDERTYPE() {
        return workordertype;
    }

    /**
     * Définit la valeur de la propriété workordertype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWORKORDERTYPE(TYPE_Type value) {
        this.workordertype = value;
    }

    /**
     * Obtient la valeur de la propriété groupwostatusid.
     * 
     * @return
     *     possible object is
     *     {@link GROUPWOSTATUSID_Type }
     *     
     */
    public GROUPWOSTATUSID_Type getGROUPWOSTATUSID() {
        return groupwostatusid;
    }

    /**
     * Définit la valeur de la propriété groupwostatusid.
     * 
     * @param value
     *     allowed object is
     *     {@link GROUPWOSTATUSID_Type }
     *     
     */
    public void setGROUPWOSTATUSID(GROUPWOSTATUSID_Type value) {
        this.groupwostatusid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/GROUPWOAUTHID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GROUPWOAUTHID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GROUPWOAUTHID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GROUPWOSTATUSID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GROUPWOAUTHID_Type", propOrder = {
    "usergroupid",
    "workordertype",
    "groupwostatusid"
})
public class GROUPWOAUTHID_Type {

    @XmlElement(name = "USERGROUPID", required = true)
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "WORKORDERTYPE", required = true)
    protected TYPE_Type workordertype;
    @XmlElement(name = "GROUPWOSTATUSID", required = true)
    protected GROUPWOSTATUSID_Type groupwostatusid;

    /**
     * Gets the value of the usergroupid property.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Sets the value of the usergroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Gets the value of the workordertype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWORKORDERTYPE() {
        return workordertype;
    }

    /**
     * Sets the value of the workordertype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWORKORDERTYPE(TYPE_Type value) {
        this.workordertype = value;
    }

    /**
     * Gets the value of the groupwostatusid property.
     * 
     * @return
     *     possible object is
     *     {@link GROUPWOSTATUSID_Type }
     *     
     */
    public GROUPWOSTATUSID_Type getGROUPWOSTATUSID() {
        return groupwostatusid;
    }

    /**
     * Sets the value of the groupwostatusid property.
     * 
     * @param value
     *     allowed object is
     *     {@link GROUPWOSTATUSID_Type }
     *     
     */
    public void setGROUPWOSTATUSID(GROUPWOSTATUSID_Type value) {
        this.groupwostatusid = value;
    }

}
